@@ -23,70 +23,61 @@ from aliyunsdkcbn.endpoint import endpoint_data
 class DetachCenChildInstanceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'DetachCenChildInstance','cbn')
+		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'DetachCenChildInstance')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_CenId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_CenId(self): # String
 		return self.get_query_params().get('CenId')
 
-	def set_CenId(self,CenId):
-		self.add_query_param('CenId',CenId)
-
-	def get_CenOwnerId(self):
+	def set_CenId(self, CenId):  # String
+		self.add_query_param('CenId', CenId)
+	def get_CenOwnerId(self): # Long
 		return self.get_query_params().get('CenOwnerId')
 
-	def set_CenOwnerId(self,CenOwnerId):
-		self.add_query_param('CenOwnerId',CenOwnerId)
-
-	def get_ChildInstanceRegionId(self):
+	def set_CenOwnerId(self, CenOwnerId):  # Long
+		self.add_query_param('CenOwnerId', CenOwnerId)
+	def get_ChildInstanceRegionId(self): # String
 		return self.get_query_params().get('ChildInstanceRegionId')
 
-	def set_ChildInstanceRegionId(self,ChildInstanceRegionId):
-		self.add_query_param('ChildInstanceRegionId',ChildInstanceRegionId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_ChildInstanceRegionId(self, ChildInstanceRegionId):  # String
+		self.add_query_param('ChildInstanceRegionId', ChildInstanceRegionId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_ChildInstanceType(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_ChildInstanceType(self): # String
 		return self.get_query_params().get('ChildInstanceType')
 
-	def set_ChildInstanceType(self,ChildInstanceType):
-		self.add_query_param('ChildInstanceType',ChildInstanceType)
-
-	def get_ChildInstanceOwnerId(self):
+	def set_ChildInstanceType(self, ChildInstanceType):  # String
+		self.add_query_param('ChildInstanceType', ChildInstanceType)
+	def get_ChildInstanceOwnerId(self): # Long
 		return self.get_query_params().get('ChildInstanceOwnerId')
 
-	def set_ChildInstanceOwnerId(self,ChildInstanceOwnerId):
-		self.add_query_param('ChildInstanceOwnerId',ChildInstanceOwnerId)
-
-	def get_ChildInstanceId(self):
+	def set_ChildInstanceOwnerId(self, ChildInstanceOwnerId):  # Long
+		self.add_query_param('ChildInstanceOwnerId', ChildInstanceOwnerId)
+	def get_ChildInstanceId(self): # String
 		return self.get_query_params().get('ChildInstanceId')
 
-	def set_ChildInstanceId(self,ChildInstanceId):
-		self.add_query_param('ChildInstanceId',ChildInstanceId)
\ No newline at end of file
+	def set_ChildInstanceId(self, ChildInstanceId):  # String
+		self.add_query_param('ChildInstanceId', ChildInstanceId)
